import multiprocessing as mp
import os.path
import pickle
import sys
import time
import warnings

from point_spectra_gui.util.themes import braceyourself, default

try:
    import qtmodern.styles

    q = True
except:
    q = False
    warnings.warn("You're missing the qtmodern package."
                  "to install it use pip install qtmodern")

from PyQt5.QtCore import *
from PyQt5.QtGui import QPixmap
from PyQt5.QtWidgets import *
from PyQt5 import QtCore, QtWidgets, QtGui
from PyQt5.QtCore import QSettings

from point_spectra_gui import core
from point_spectra_gui.ui import MainWindow
from point_spectra_gui.util import delete
from point_spectra_gui.util.BasicFunctionality import Basics
from point_spectra_gui.util.excepthook import my_exception_hook


class EmittingStream(QtCore.QObject):
    textWritten = QtCore.pyqtSignal(str)

    def write(self, text):
        self.textWritten.emit(str(text))

    def flush(self):
        pass


class TitleWindow:
    def __init__(self, mainName):
        self.mainName = mainName
        self.fileName = ''
        self.debugName = ''

    def setMainName(self, name):
        self.mainName = name

    def setFileName(self, name):
        self.fileName = name

    def setDebugName(self, bool):
        if bool:
            self.debugName = "Debug Mode"
        else:
            self.debugName = ''

    def display(self):
        if self.fileName == '' and self.debugName == '':
            return "{}".format(self.mainName)
        elif self.fileName == '':
            return "{} - {}".format(self.mainName, self.debugName)
        elif self.debugName == '':
            return "{} - {}".format(self.mainName, self.fileName)
        else:
            return "{} - {} - {}".format(self.mainName, self.fileName, self.debugName)


class Ui_MainWindow(MainWindow.Ui_MainWindow, QtCore.QThread, Basics):
    taskFinished = QtCore.pyqtSignal()

    def __init__(self):
        super().__init__()
        self.widgetList = []
        self.leftOff = 0

    def setupUi(self, MainWindow):
        super().setupUi(MainWindow)  # Run the basic window UI
        self.MainWindow = MainWindow
        self.MainWindow.closeEvent = self.closeEvent
        self.title = TitleWindow(self.MainWindow.windowTitle())
        self._readAndApplyWindowAttributeSettings()
        self.menu_item_shortcuts()  # set up the shortcuts
        self.connectWidgets()

        # Check the mode for debugging
        if self.settings.value("debug") == 'true':
            self.debug_mode()
        else:
            self.normal_mode()

        # Check the theme for the UI
        if self.settings.value('theme') == 'braceyourself':
            braceyourself(self.MainWindow)

    def normal_mode(self):
        """
        Change the direction of stdout to print to the UI console instead
        :return:
        """
        sys.stdout = EmittingStream(textWritten=self.normalOutputWritten)
        sys.stderr = sys.__stderr__
        # sys.stderr = EmittingStream(textWritten=self.normalOutputWritten)
        self._mode(self.actionOn, self.actionOff, False)

    def debug_mode(self):
        """
        Change the direction of stdout to print to the original console
        :return:
        """
        # Restore sys.stdout
        sys.stdout = sys.__stdout__
        self._mode(self.actionOff, self.actionOn, True)

    def _mode(self, obj1, obj2, debug):
        """
        Set the UI in debug or non-debug mode
        Save all the settings and grey out the necessary boxes
        :param obj1:
        :param obj2:
        :param debug:
        :return:
        """
        obj1.setDisabled(False)
        obj2.setDisabled(True)
        self.debug = debug
        self.title.setDebugName(debug)
        self.settings.setValue("debug", self.debug)
        self.MainWindow.setWindowTitle(self.title.display())

    def theme(self, name):
        """
        We have 3 themes
        each has a different situation
                   __________________
                 /__               __\ new()   Something to note:
               v    \            v    \ new()  As you can see whenever moving into or out of
        default     braceyourself    qtmodern  qtmodern we will have to start a new session
               \___^             \___^ new()   default and braceyourself can simply change
                \___________________/ new()    there styling on the spot

        :param name:
        :return:
        """
        settings = self.settings.value('theme')
        if name == settings:
            print("This is already your current theme")

        if name == 'qtmodern':  # User is entering into qtmodern
            self.settings.setValue('theme', name)
            self.new()

        elif settings == 'qtmodern':  # User is leaving qtmodern
            self.settings.setValue('theme', name)
            self.new()

        elif name == 'default':
            self.settings.setValue('theme', name)
            default(self.MainWindow)

        elif name == 'braceyourself':
            self.settings.setValue('theme', name)
            braceyourself(self.MainWindow)
        else:
            print("Something went horribly wrong with your theme, try again?")

    def normalOutputWritten(self, text):
        """Append text to the QTextEdit."""
        # Maybe QTextEdit.append() works as well, but this is how I do it:
        cursor = self.textBrowser.textCursor()
        cursor.movePosition(QtGui.QTextCursor.End)
        cursor.insertText(text)
        self.textBrowser.setTextCursor(cursor)
        self.textBrowser.ensureCursorVisible()

    def addWidget(self, obj):
        """
        Organize our widgets using a list
        Each widget is addressed separately due to being in a list
        :param obj:
        :return:
        """
        self.widgetList.append(obj())
        self.widgetList[-1].setupUi(self.centralwidget)
        self.widgetLayout = QtWidgets.QVBoxLayout()
        self.widgetLayout.setObjectName("widgetLayout")
        self.verticalLayout_3.addLayout(self.widgetLayout)
        self.widgetLayout.addWidget(self.widgetList[-1].get_widget())

    def menu_item_shortcuts(self):
        self.actionExit.setShortcut("ctrl+Q")
        self.actionCreate_New_Workflow.setShortcut("ctrl+N")
        self.actionRestore_Workflow.setShortcut("ctrl+O")
        self.actionSave_Current_Workflow.setShortcut("ctrl+S")
        self.okPushButton.setShortcut("Ctrl+Return")

    def connectWidgets(self):
        """
        Connect all the widgets associated with the MainWindow UI
        :return:
        """
        # TODO figure out how to get this code into `MainWindow.py`
        self.addWidget(core.ReadChemCamData.ReadChemCamData)
        self.addWidget(core.BaselineRemoval.BaselineRemoval)
        self.addWidget(core.CrossValidation.CrossValidation)
        self.addWidget(core.DimensionalityReduction.DimensionalityReduction)
        self.addWidget(core.Interpolation.Interpolation)
        self.addWidget(core.LoadData.LoadData)
        self.addWidget(core.WriteToCSV.WriteToCSV)
        self.addWidget(core.RenameData.RenameData)
        self.addWidget(core.MaskData.MaskData)
        self.addWidget(core.MultiplyByVector.MultiplyByVector)
        self.addWidget(core.Normalization.Normalization)
        self.addWidget(core.OutputFolder.OutputFolder)
        self.addWidget(core.PeakAreas.PeakAreas)
        self.addWidget(core.Plot.Plot)
        self.addWidget(core.Plot_ICA_PCA.Plot_ICA_PCA)
        self.addWidget(core.PlotSpectra.PlotSpectra)
        self.addWidget(core.RegressionTrain.RegressionTrain)
        self.addWidget(core.RegressionPredict.RegressionPredict)
        self.addWidget(core.RemoveRows.RemoveRows)
        self.addWidget(core.SplitDataset.SplitDataset)
        self.addWidget(core.StratifiedFolds.StratifiedFolds)
        self.addWidget(core.SubmodelPredict.SubmodelPredict)
        time.sleep(5)
        sys.exit()

    def closeEvent(self, event):
        """
        Write window size and position to config file
        """
        self._writeWindowAttributeSettings()
        event.accept()

    def getWidgetItems(self):
        """
        This function iterates through widgetList
        gets the name of all the fuctions
        and then all of the parameters in the UI
        and write it to a list to be returned

        Iterate through widgetList
        get the names of core, add it to a temp l
        add f list to be the first item in ui_items
        """
        f = []
        ui_items = []
        for f_items in self.widgetList:
            f.append(type(f_items).__name__)
        ui_items.append(f)

        for dat in self.widgetList:
            ui_items.append(dat.getGuiParams())
        return ui_items

    def setWidgetItems(self, dict):
        """
        This function iterates through a `dict`
        and restores the UI
        :param dict:
        :return:
        """
        for f_items in dict[0]:
            """
            Really complex way of running essentially this:
            `self.addWidget(core.SplitDataset.SplitDataset))`
            Part of the reason why we're doing this is because we're saving function
            names to a list, you can't save function instances. So this is the next
            best thing.
            """
            self.addWidget(getattr(getattr(core, f_items), f_items))

        for i in range(1, len(dict)):
            self.widgetList[i - 1].setGuiParams(dict[i])

    def on_save_clicked(self):
        """
        Save the workflow to a *.wrf file
        :return:
        """
        try:
            filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None,
                                                                      "Choose where you want save your file",
                                                                      self.outpath,
                                                                      '(*.wrf)')
            print(filename)
            with open(filename, 'wb') as fp:
                pickle.dump(self.getWidgetItems(), fp)
            self.title.setFileName(filename.split('/')[-1])
            self.MainWindow.setWindowTitle(self.title.display())
        except Exception as e:
            print("File not loaded {}".format(e))

    def on_restore_clicked(self):
        """
        Choose a file
        Set the file to be read
        Pickle load our data and push it through the function setWidgetItems
        :return:
        """
        try:
            filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None,
                                                                      "Open Workflow File",
                                                                      self.outpath,
                                                                      '(*.wrf)')
            print(filename)
            with open(filename, 'rb') as fp:
                self.setWidgetItems(pickle.load(fp))
            self.title.setFileName(filename.split('/')[-1])
            self.MainWindow.setWindowTitle(self.title.display())
        except Exception as e:
            print("File not loaded: {}".format(e))

    def on_delete_module_clicked(self):
        """
        Check to see if the last item is enabled
        If it is, delete the last item in the list
        And then call the del_layout function, which will remove the item from the UI
        :return:
        """
        try:
            if self.widgetList[-1].isEnabled():
                del self.widgetList[-1]
                delete.del_layout(self.verticalLayout_3)
            else:
                print("Cannot delete")
        except:
            print("Cannot delete")

    def on_okButton_clicked(self):
        self.onStart()
        self.taskFinished.connect(self.onFinished)

    def on_undoButton_clicked(self):
        """
        Check to see if the last item in the list is enabled
        subtract 1 from leftOff
        enable the current leftOff item
        :return:
        """
        try:
            if not self.widgetList[-1].isEnabled():
                self.leftOff -= 1
                self.widgetList[self.leftOff].setDisabled(False)
        except:
            pass

    def on_stopButton_clicked(self):
        if self.isRunning():
            self.terminate()
            self.taskFinished.emit()
        else:
            print("There is nothing running right now")

    def _writeWindowAttributeSettings(self):
        '''
        Save window attributes as settings.

        Called when window moved, resized, or closed.
        '''
        self.settings.beginGroup("mainWindow")
        self.settings.setValue("pos", self.MainWindow.pos())
        self.settings.setValue("maximized", self.MainWindow.isMaximized())
        self.settings.setValue('splitter', self.splitter.saveState())
        if not self.MainWindow.isMaximized():
            self.settings.setValue("size", self.MainWindow.size())

        self.settings.endGroup()

    def _readAndApplyWindowAttributeSettings(self):
        '''
        Read window attributes from settings,
        using current attributes as defaults (if settings not exist.)

        Called at QMainWindow initialization, before show().
        '''
        self.settings.beginGroup("mainWindow")
        # No need for toPoint, etc. : PySide converts types
        try:
            self.splitter.restoreState(self.settings.value('splitter'))
            self.MainWindow.move(self.settings.value("pos"))
            if self.settings.value("maximized") in 'true':
                self.MainWindow.showMaximized()
            else:
                self.MainWindow.resize(self.settings.value("size"))
        except:
            pass
        self.settings.endGroup()

    def onStart(self):  # onStart function
        self.progressBar.setRange(0, 0)  # make the bar pulse green
        self.start()  # TaskThread.start()
        # This is multithreading thus run() == start()

    def onFinished(self):  # onFinished function
        self.progressBar.setRange(0, 1)  # stop the bar pulsing green
        self.progressBar.setValue(1)  # displays 100% after process is finished.

    def clear(self):
        while len(self.widgetList) > 0 and self.widgetList[-1].isEnabled():
            self.on_delete_module_clicked()
        self.title.setFileName('')
        self.MainWindow.setWindowTitle(self.title.display())
        self.textBrowser.clear()

    def new(self):
        p = mp.Process(target=main, args=())
        p.start()

    def run(self):
        if self.debug:
            for modules in range(self.leftOff, len(self.widgetList)):
                name_ = type(self.widgetList[modules]).__name__
                s = time.time()
                print("{} Module is Running...".format(name_))
                self.widgetList[modules].function()
                e = time.time()
                print("Module {} executed in: {} seconds".format(name_, e - s))
                self.widgetList[modules].setDisabled(True)
                self.leftOff = modules + 1
            self.taskFinished.emit()

        else:
            try:
                for modules in range(self.leftOff, len(self.widgetList)):
                    name_ = type(self.widgetList[modules]).__name__
                    s = time.time()
                    print("{} Module is Running...".format(name_))
                    self.widgetList[modules].function()
                    e = time.time()
                    print("Module {} executed in: {} seconds".format(name_, e - s))
                    self.widgetList[modules].setDisabled(True)
                    self.leftOff = modules + 1
                self.taskFinished.emit()
            except Exception as e:
                print("Your module broke: please fix.", e)
                self.widgetList[self.leftOff].setDisabled(False)
                self.taskFinished.emit()


def get_splash(app):
    """
    Get the splash screen for the application
    But check to see if the image even exists
    :param app:
    :return:
    """
    dirs = ['../images/', '/point_spectra_gui/images', './point_spectra_gui/images']
    for dir in dirs:
        if os.path.exists(dir + 'splash.png'):
            splash_pix = QPixmap(dir + 'splash.png')  # default
            app_icon = QtGui.QIcon(dir + 'icon.png')
            app.setWindowIcon(app_icon)
            splash = QSplashScreen(splash_pix, Qt.WindowStaysOnTopHint)
            splash.setMask(splash_pix.mask())
            splash.show()
            time.sleep(0.5)
            app.processEvents()
            return 0


def setDarkmode(app):
    settings = QSettings('USGS', 'PPSG')
    p = settings.value('theme') == 'qtmodern'
    if q and p:
        qtmodern.styles.dark(app)


def main():
    sys._excepthook = sys.excepthook
    sys.excepthook = my_exception_hook
    app = QtWidgets.QApplication(sys.argv)
    get_splash(app)
    setDarkmode(app)
    mainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(mainWindow)
    mainWindow.show()
    sys.exit(app.exec_())


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.regrLabel = QtWidgets.QLabel(self.formGroupBox)
        self.regrLabel.setObjectName("regrLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.regrLabel)
        self.regrComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.regrComboBox.setObjectName("regrComboBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.regrComboBox)
        self.corrLabel = QtWidgets.QLabel(self.formGroupBox)
        self.corrLabel.setObjectName("corrLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.corrLabel)
        self.corrComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.corrComboBox.setObjectName("corrComboBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.corrComboBox)
        self.storageModeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.storageModeLabel.setObjectName("storageModeLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.storageModeLabel)
        self.storageModeComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.storageModeComboBox.setObjectName("storageModeComboBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.storageModeComboBox)
        self.verboseLabel = QtWidgets.QLabel(self.formGroupBox)
        self.verboseLabel.setObjectName("verboseLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.verboseLabel)
        self.verboseCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.verboseCheckBox.setObjectName("verboseCheckBox")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.verboseCheckBox)
        self.theta0Label = QtWidgets.QLabel(self.formGroupBox)
        self.theta0Label.setObjectName("theta0Label")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.theta0Label)
        self.optimizerLabel = QtWidgets.QLabel(self.formGroupBox)
        self.optimizerLabel.setObjectName("optimizerLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.optimizerLabel)
        self.optimizerComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.optimizerComboBox.setObjectName("optimizerComboBox")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.optimizerComboBox)
        self.randomStartLabel = QtWidgets.QLabel(self.formGroupBox)
        self.randomStartLabel.setObjectName("randomStartLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.randomStartLabel)
        self.randomStartSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.randomStartSpinBox.setObjectName("randomStartSpinBox")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.randomStartSpinBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.theta0DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.theta0DoubleSpinBox.setObjectName("theta0DoubleSpinBox")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.theta0DoubleSpinBox)
        self.reductionMethodComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.reductionMethodComboBox.setObjectName("reductionMethodComboBox")
        self.reductionMethodComboBox.addItem("")
        self.reductionMethodComboBox.addItem("")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.reductionMethodComboBox)
        self.reductionMethodLabel = QtWidgets.QLabel(self.formGroupBox)
        self.reductionMethodLabel.setObjectName("reductionMethodLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.reductionMethodLabel)
        self.numOfComponenetsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfComponenetsLabel.setObjectName("numOfComponenetsLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.numOfComponenetsLabel)
        self.numOfComponenetsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.numOfComponenetsSpinBox.setObjectName("numOfComponenetsSpinBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.numOfComponenetsSpinBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("Gaussian Process"))
        self.regrLabel.setText(("Regression Types"))
        self.corrLabel.setText(("Correlation Types"))
        self.storageModeLabel.setText(("Storage Mode"))
        self.verboseLabel.setText(("Verbose"))
        self.theta0Label.setText(("Theta 0"))
        self.optimizerLabel.setText(("Optimizer Types"))
        self.randomStartLabel.setText(("Random Start"))
        self.normalizeLabel.setText(("Normalize"))
        self.reductionMethodComboBox.setItemText(0, ("PCA"))
        self.reductionMethodComboBox.setItemText(1, ("ICA"))
        self.reductionMethodLabel.setText(("Choose dimensionality reduction method:"))
        self.numOfComponenetsLabel.setText(("Number of Components"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from Qtickle import Qtickle
from pysat.spectral.spectral_data import spectral_data
from point_spectra_gui.core.baselineRemovalMethods import *
from point_spectra_gui.ui.BaselineRemoval import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics



class BaselineRemoval(Ui_Form, Basics):
    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Basics.setupUi(self, Form)
        self.baselineMethods()

    def get_widget(self):
        return self.formGroupBox

    def make_regression_widget(self, alg, params=None):
        self.hideAll()
        print(alg)
        for i in range(len(self.chooseAlgorithmList)):
            if alg == self.chooseAlgorithmList[i] and i > 0:
                self.alg[i - 1].setHidden(False)

    def connectWidgets(self):
        self.chooseAlgorithmList = ['Choose an algorithm',
                                    'AirPLS',
                                    'ALS',
                                    'Dietrich',
                                    'FABC',
                                    'KK',
                                    'Median',
                                    'Polyfit',
                                    'Rubberband',
                                    'CCAM',
                                    'Mario (Coming soon)',
                                    ]
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseAlgorithmComboBox, self.chooseAlgorithmList)
        self.chooseAlgorithmComboBox.currentIndexChanged.connect(
            lambda: self.make_regression_widget(self.chooseAlgorithmComboBox.currentText()))

    def getGuiParams(self):
        """
        Overriding Basics' getGuiParams, because I'll need to do a list of lists
        in order to obtain the regressionMethods' parameters
        """
        self.qt = Qtickle.Qtickle(self)
        s = []
        s.append(self.qt.guiSave())
        for items in self.alg:
            s.append(items.getGuiParams())
        return s

    def setGuiParams(self, dict):
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict[0])
        for i in range(len(dict)):
            self.alg[i - 1].setGuiParams(dict[i])

    def function(self):
        method = self.chooseAlgorithmComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()

        methodParameters = self.getMethodParams(self.chooseAlgorithmComboBox.currentIndex())

        datakey_new = datakey + '-Baseline Removed-' + method + str(methodParameters)
        datakey_baseline = datakey + '-Baseline-' + method + str(methodParameters)
        self.datakeys.append(datakey_new)
        self.datakeys.append(datakey_baseline)
        self.data[datakey_new] = spectral_data(self.data[datakey].df.copy(deep=True))
        self.data[datakey_new].remove_baseline(method, segment=True, params=methodParameters)
        self.data[datakey_baseline] = spectral_data(self.data[datakey_new].df_baseline)

    def hideAll(self):
        for a in self.alg:
            a.setHidden(True)

    def getMethodParams(self, index):
        return self.alg[index - 1].function()

    def baselineMethods(self):
        self.alg = []
        list_forms = [
            AirPLS,
            ALS,
            Dietrich,
            FABC,
            KK,
            Median,
            Polyfit,
            Rubberband,
            CCAM,
            Mario,
        ]
        for items in list_forms:
            self.alg.append(items.Ui_Form())
            self.alg[-1].setupUi(self.Form)
            self.algorithmLayout.addWidget(self.alg[-1].get_widget())
            self.alg[-1].setHidden(True)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = BaselineRemoval()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets
from pysat.plotting.plots import pca_ica_plot

from point_spectra_gui.ui.Plot_ICA_PCA import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Plot_ICA_PCA(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        alg_choices = ['Choose a method', 'PCA', 'FastICA']#, 'ICA-JADE']
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseMethodComboBox, alg_choices)
        self.colorchoices_change_vars(self.colorCodedVariableComboBox)
        self.pushButton.clicked.connect(self.on_plotFilenamePushButton_clicked)
        self.chooseMethodComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.chooseXVariableComboBox, self.xychoices()))
        self.chooseMethodComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.chooseYVariableComboBox, self.xychoices()))

    def function(self):
        cmap = 'viridis'
        datakey = self.chooseDataComboBox.currentText()
        method = self.chooseMethodComboBox.currentText()
        x_component = self.chooseXVariableComboBox.currentText()
        y_component = self.chooseYVariableComboBox.currentText()
        if self.colorCodedVariableComboBox.currentText() != 'None':
            colorvar = self.colorCodedVariableComboBox.currentText()
        else:
            colorvar = None
        filename = self.plotFilenameLineEdit.text()
        figpath, figfile = '/'.join(filename.split('/')[:-1]), filename.split('/')[-1]
        pca_ica_plot(self.data[datakey], x_component, y_component, colorvar=colorvar, cmap=cmap, method=method,
                     figpath=figpath, figfile=figfile)

    def xychoices(self):
        try:
            choices = self.data[self.chooseDataComboBox.currentText()].df[
                self.chooseMethodComboBox.currentText()].columns.values
        except Exception as e:
            print(e)
            choices = ['-']
        return choices

    def on_plotFilenamePushButton_clicked(self):
        filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None, "Save Plot", self.outpath, "(*.png)")
        self.plotFilenameLineEdit.setText(filename)
        if self.plotFilenameLineEdit.text() == "":
            self.plotFilenameLineEdit.setText("*.png")

    def colorchoices_change_vars(self, obj):
        obj.clear()
        choices = ['None']
        try:
            self.vars_level0 = self.data[
                self.chooseDataComboBox.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[
                self.chooseDataComboBox.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = self.vars_level1[self.vars_level0 != 'wvl']
            self.vars_level0 = self.vars_level0[self.vars_level0 != 'wvl']
            self.vars_level1 = list(self.vars_level1[self.vars_level0 != 'masked'])
            self.vars_level0 = list(self.vars_level0[self.vars_level0 != 'masked'])
            try:
                self.vars_level0 = [i for i in self.vars_level0 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except Exception as e:
                print(e)
                pass
            try:
                self.vars_level1 = [i for i in self.vars_level1 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except Exception as e:
                print(e)
                pass
            for i in self.vars_level1:
                choices.append(str(i))

        except Exception as e:
            print(e)
            try:
                choices.append(self.data[self.chooseDataComboBox.currentText()].columns.values)
            except Exception as e:
                print(e)
                pass
        for i in choices:
            obj.addItem(str(i))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = Plot_ICA_PCA()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import numpy as np
from PyQt5 import QtWidgets
from Qtickle import Qtickle
from pysat.regression import cv
from pysat.spectral.spectral_data import spectral_data
from point_spectra_gui.ui.CrossValidation import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics



class CrossValidation(Ui_Form, Basics):
    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Basics.setupUi(self, Form)
        self.regressionMethods()

    def get_widget(self):
        return self.groupLayout

    def make_regression_widget(self, alg, params=None):
        self.hideAll()
        print(alg)
        for i in range(len(self.algorithm_list) - 1):
            if alg == self.algorithm_list[i] and i > 0:
                self.alg[i - 1].setHidden(False)

    def connectWidgets(self):
        self.algorithm_list = ['Choose an algorithm',
                               'PLS',
                               'GP',
                               'More to come...']
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseAlgorithmComboBox, self.algorithm_list)
        self.yMaxDoubleSpinBox.setMaximum(999999)
        self.yMinDoubleSpinBox.setMaximum(999999)
        self.yMaxDoubleSpinBox.setValue(100)
        self.changeComboListVars(self.yVariableList, self.yvar_choices())
        self.changeComboListVars(self.xVariableList, self.xvar_choices())
        self.xvar_choices()
        self.chooseAlgorithmComboBox.currentIndexChanged.connect(
            lambda: self.make_regression_widget(self.chooseAlgorithmComboBox.currentText()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.yVariableList, self.yvar_choices()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.xVariableList, self.xvar_choices()))

    def getGuiParams(self):
        """
        Overriding Basics' getGuiParams, because I'll need to do a list of lists
        in order to obtain the regressionMethods' parameters
        """
        self.qt = Qtickle.Qtickle(self)
        s = []
        s.append(self.qt.guiSave())
        for items in self.alg:
            s.append(items.getGuiParams())
        return s

    def setGuiParams(self, dict):
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict[0])
        for i in range(len(dict)):
            self.alg[i - 1].setGuiParams(dict[i])

    def function(self):
        method = self.chooseAlgorithmComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()
        xvars = [str(x.text()) for x in self.xVariableList.selectedItems()]
        yvars = [('comp', str(y.text())) for y in self.yVariableList.selectedItems()]
        yrange = [self.yMinDoubleSpinBox.value(), self.yMaxDoubleSpinBox.value()]
        params, modelkey = self.getMethodParams(self.chooseAlgorithmComboBox.currentIndex())
        modelkey = method + ' - ' + str(yvars[0][-1]) + ' (' + str(yrange[0]) + '-' + str(yrange[1]) + ') '
        print(params, modelkey)

        y = np.array(self.data[datakey].df[yvars])
        match = np.squeeze((y > yrange[0]) & (y < yrange[1]))
        data_for_cv = spectral_data(self.data[datakey].df.ix[match])
        # Warning: Params passing through cv.cv(params) needs to be in lists
        # Example: {'n_components': [4], 'scale': [False]}
        cv_obj = cv.cv(params)
        self.data[datakey].df, self.cv_results = cv_obj.do_cv(data_for_cv.df, xcols=xvars, ycol=yvars,
                                                              yrange=yrange, method=method)
        self.datakeys.append('CV Results ' + modelkey)
        self.data['CV Results ' + modelkey] = self.cv_results

    def yvar_choices(self):
        try:
            yvarchoices = self.data[self.chooseDataComboBox.currentText()].df['comp'].columns.values
            yvarchoices = [i for i in yvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            yvarchoices = ['No composition columns!']
        return yvarchoices

    def xvar_choices(self):
        try:
            xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[0].values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices

    def hideAll(self):
        for a in self.alg:
            a.setHidden(True)

    def getMethodParams(self, index):
        return self.alg[index - 1].function()

    def regressionMethods(self):
        self.alg = []
        list_forms = [PLS,
                      GP,
                      ]
        for items in list_forms:
            self.alg.append(items.Ui_Form())
            self.alg[-1].setupUi(self.Form)
            self.algorithmLayout.addWidget(self.alg[-1].get_widget())
            self.alg[-1].setHidden(True)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = CrossValidation()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import inspect
import sys
from PyQt5.QtCore import QSettings
from PyQt5.QtWidgets import *
from Qtickle import Qtickle



class Basics:
    """
    This class is a scaffolding class, it holds global
    functionality for all classes inheriting from it.
    It is here to simplify and globalize certain
    variables and functionalities to each of the
    UI classes.

    *Note: Rigorous prototyping is still occurring
    So, naturally, assume that something in this class
    is always getting changed or added to better serve
    all cases in each UI class.

    ...

    Since `Basics` is shared among all the UI
    classes it would make sense that we would have
    some variables, that are necessary among all these
    classes, be put here in a high place where they
    can be referenced often.
    """
    data = {}  # initialize with an empty dict to hold data frames
    datakeys = []  # hold all the specific key for a specific data frame
    modelkeys = []
    outpath = './'  # Default outpath; can be changed with OutputFolder.py
    figs = {}
    figname = []
    models = {}  # For regression training
    model_xvars = {}
    model_yvars = {}

    def __init__(self):
        self.qt = Qtickle.Qtickle(self)
        self.settings = QSettings('USGS', 'PPSG')

    def setupUi(self, Form):
        self.Form = Form
        self.Form.mousePressEvent = self.mousePressEvent
        self.connectWidgets()

    def mousePressEvent(self, QMouseEvent):
        """
        Right click event
        """
        # TODO Add mouse Event
        # print("Right Button Clicked {}".format(type(self).__name__))

    def get_widget(self):
        """
        This function specifies the variable that holds the
        styling. Use this function to get the variable
        :return:
        """
        sys.exit('Error: Application closed unexpectedly\n'
                 'The method "get_widget()" was not found in this module')

    def connectWidgets(self):
        """
        Connect the necessary widgets.
        :return:
        """
        sys.exit('Error: Application closed unexpectedly\n'
                 'The method "connectWidgets()" was not found in this module')

    def getGuiParams(self):
        """
        Return the contents from lineEdits, comboBoxes, etc.
        :return:
        """
        self.qt = Qtickle.Qtickle(self)
        s = self.qt.guiSave()
        return s

    def setGuiParams(self, dict):
        """
        Using a dictionary, restore the UI
        :param dict:
        :return:
        """
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict)

    def function(self):
        """
        Each Module's functionality will be ran in this function.
        You will define what will happen to the data and parameters in here
        :return:
        """
        sys.exit('Error: Application closed unexpectedly\n'
                 'The method "function()" was not found in this module')

    def isEnabled(self):
        """
        Checks to see if current widget isEnabled or not
        :return:
        """
        return self.get_widget().isEnabled()

    def setDisabled(self, bool):
        """
        After every execution we want to prevent the user from changing something.
        So, disable the layout by greying it out
        :param bool:
        :return:
        """
        self.get_widget().setDisabled(bool)

    def setProgressBar(self, progressBar):
        """
        This function makes it possible to reference the progress bar
        in MainWindow
        :param progressBar:
        :return:
        """
        self.progressBar = progressBar

    def checkMinAndMax(self):
        """
        Go through the entire UI and set the maximums and minimums of each widget
        :return:
        """
        for name, obj in inspect.getmembers(self):
            if isinstance(obj, QSpinBox):
                obj.setMaximum(999999)

            if isinstance(obj, QDoubleSpinBox):
                obj.setDecimals(7)

    @staticmethod
    def setComboBox(comboBox, keyValues):
        """
        Sets up the information inside comboBox widgets
        This function does not need to be overridden.
        :param comboBox:
        :param keyValues:
        :return:
        """
        for i, choice in enumerate(keyValues):
            comboBox.addItem("")
            comboBox.setItemText(i, str(choice))

    @staticmethod
    def changeComboListVars(obj, newchoices):
        """
        Function changes combo boxes
        This function does not need to be overridden.
        :param obj:
        :param newchoices:
        :return:
        """
        obj.clear()
        for i in newchoices:
            if isinstance(i, tuple):
                obj.addItem(i[1])
            elif isinstance(i, str):
                obj.addItem(i)

    @staticmethod
    def setListWidget(obj, choices):
        """
        Function changes lists
        This function does not need to be overridden
        :param obj:
        :param choices:
        :return:
        """
        for item in choices:
            obj.addItem(item)

    @staticmethod
    def defaultComboItem(obj, item):
        """
        Set the default selected item in a box.
        :param obj:
        :param item:
        :return:
        """
        obj.setCurrentIndex(obj.findText(str(item)))



import numpy as np
from PyQt5 import QtWidgets
from pysat.spectral.spectral_data import spectral_data

from point_spectra_gui.ui.RemoveRows import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class RemoveRows(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.colNameComboBox, self.get_colname_choices())
        self.setComboBox(self.valueComboBox, self.get_rowval_choices())
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.colNameComboBox, self.get_colname_choices()))
        self.colNameComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.valueComboBox, self.get_rowval_choices()))

    def function(self):
        datakey = self.chooseDataComboBox.currentText()
        colname = self.colNameComboBox.currentText()
        value = self.valueComboBox.currentText()
        value = value.split(' : ')[0]
        print(datakey, colname, value)
        print(self.data[datakey].df.shape)
        vars_level0 = self.data[datakey].df.columns.get_level_values(0)
        vars_level1 = self.data[datakey].df.columns.get_level_values(1)
        vars_level1 = list(vars_level1[vars_level0 != 'wvl'])
        vars_level0 = list(vars_level0[vars_level0 != 'wvl'])
        colname = (vars_level0[vars_level1.index(colname)], colname)

        if value == 'Null':
            self.data[datakey] = spectral_data(self.data[datakey].df.ix[-self.data[datakey].df[colname].isnull()])
        else:
            # find where the values in the specified column match the value to be removed
            coldata = np.array([str(i) for i in self.data[datakey].df[colname]])
            match = coldata == value
            # keep everything except where match is true
            self.data[datakey] = spectral_data(self.data[datakey].df.ix[~match])
        print(self.data[datakey].df.shape)

    def get_colname_choices(self):
        try:
            self.vars_level0 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = list(
                self.vars_level1[np.logical_and(self.vars_level0 != 'wvl', self.vars_level0 != 'masked')])
            self.vars_level0 = list(
                self.vars_level0[np.logical_and(self.vars_level0 != 'wvl', self.vars_level0 != 'masked')])

            colnamechoices = self.vars_level1

        except:
            try:
                colnamechoices = self.data[self.chooseDataComboBox.currentText()].columns.values
            except:
                colnamechoices = []
        colnamechoices = [i for i in colnamechoices if not 'Unnamed' in str(i)]  # remove unnamed columns from choices
        return colnamechoices

    def get_rowval_choices(self):
        try:
            colname = self.colNameComboBox.currentText()
            colname = (self.vars_level0[self.vars_level1.index(colname)], colname)
            choices = self.data[self.chooseDataComboBox.currentText()].df[colname]
            # choices = choices[~np.isnan(choices)]
            # nchoices2 = choices.size
            nchoice = []
            choices = [str(i) for i in choices]
            for choice in choices:
                if not choice + ' : ' + str(choices.count(choice)) in nchoice:
                    nchoice.append(choice + ' : ' + str(choices.count(choice)))
            choices = nchoice
        except:
            choices = ['-']
        return choices


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = RemoveRows()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets
from sklearn.linear_model import ARDRegression

from point_spectra_gui.ui.ARD import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, ARDRegression, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()


    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.numOfIterationsSpinBox.setValue(self.n_iter)
        self.toleranceDoubleSpinBox.setValue(self.tol)
        self.alpha1DoubleSpinBox.setValue(self.alpha_1)
        self.alpha2DoubleSpinBox.setValue(self.alpha_2)
        self.lambdaDoubleSpinBox.setValue(self.lambda_1)
        self.lambdaDoubleSpinBox_2.setValue(self.lambda_2)
        self.computerScoreCheckBox.setChecked(self.compute_score)
        self.thresholdLambdaSpinBox.setValue(self.threshold_lambda)
        self.fitInterceptCheckBox.setChecked(self.fit_intercept)
        self.normalizeCheckBox.setChecked(self.normalize)
        self.copyXCheckBox.setChecked(self.copy_X)
        self.verboseCheckBox.setChecked(self.verbose)

    def function(self):
        params = {
            'n_iter': self.numOfIterationsSpinBox.value(),
            'tol': self.toleranceDoubleSpinBox.value(),
            'alpha_1': self.alpha1DoubleSpinBox.value(),
            'alpha_2': self.alpha2DoubleSpinBox.value(),
            'lambda_1': self.lambdaDoubleSpinBox.value(),
            'lambda_2': self.lambdaDoubleSpinBox_2.value(),
            'compute_score': self.computerScoreCheckBox.isChecked(),
            'threshold_lambda': self.thresholdLambdaSpinBox.value(),
            'fit_intercept': self.fitInterceptCheckBox.isChecked(),
            'normalize': self.normalizeCheckBox.isChecked(),
            'copy_X': self.copyXCheckBox.isChecked(),
            'verbose': self.verboseCheckBox.isChecked()}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets
from pysat.spectral.baseline_code.mario import Mario

from point_spectra_gui.ui.Mario import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.connectWidgets()
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        br = Mario()
        # This algorithm doesn't work for now, but let the user get a sneak peek of it.
        self.get_widget().setDisabled(True)
        self.polynomialOrderSpinBox.setValue(br.poly_order_)
        self.toleranceDoubleSpinBox.setValue(br.tol_)

    def function(self):
        maxNIDSpinBox = float(self.maximumNumOfIterationsDoubleSpinBox.value())
        if maxNIDSpinBox == 0:
            maxNIDSpinBox = None
        methodParameters = {'poly_order_': int(self.polynomialOrderSpinBox.value()),
                            'max_iters_': maxNIDSpinBox,
                            'tol_': float(self.toleranceDoubleSpinBox.value())}
        return methodParameters


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.numOfIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfIterationsLabel.setObjectName("numOfIterationsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numOfIterationsLabel)
        self.numOfIterationsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.numOfIterationsLineEdit.setProperty("maximum", 999999999)
        self.numOfIterationsLineEdit.setProperty("value", 300)
        self.numOfIterationsLineEdit.setObjectName("numOfIterationsLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numOfIterationsLineEdit)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.toleranceLineEdit.setProperty("decimals", 8)
        self.toleranceLineEdit.setProperty("singleStep", 0.001)
        self.toleranceLineEdit.setProperty("value", 0.001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.alpha1Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha1Label.setObjectName("alpha1Label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.alpha1Label)
        self.alpha1LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha1LineEdit.setProperty("decimals", 5)
        self.alpha1LineEdit.setProperty("singleStep", 0.001)
        self.alpha1LineEdit.setProperty("value", 0.001)
        self.alpha1LineEdit.setObjectName("alpha1LineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.alpha1LineEdit)
        self.alpha2Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha2Label.setObjectName("alpha2Label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.alpha2Label)
        self.alpha2LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha2LineEdit.setProperty("decimals", 8)
        self.alpha2LineEdit.setProperty("singleStep", 1e-06)
        self.alpha2LineEdit.setProperty("value", 1e-06)
        self.alpha2LineEdit.setObjectName("alpha2LineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.alpha2LineEdit)
        self.lambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel.setObjectName("lambdaLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel)
        self.lambdaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambdaLineEdit.setProperty("decimals", 8)
        self.lambdaLineEdit.setProperty("singleStep", 1e-06)
        self.lambdaLineEdit.setProperty("value", 1e-06)
        self.lambdaLineEdit.setObjectName("lambdaLineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lambdaLineEdit)
        self.computerScoreLabel = QtWidgets.QLabel(self.formGroupBox)
        self.computerScoreLabel.setObjectName("computerScoreLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.computerScoreLabel)
        self.computerScoreCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.computerScoreCheckBox.setObjectName("computerScoreCheckBox")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.computerScoreCheckBox)
        self.thresholdLambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.thresholdLambdaLabel.setObjectName("thresholdLambdaLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.thresholdLambdaLabel)
        self.thresholdLambdaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.thresholdLambdaLineEdit.setProperty("maximum", 999999999)
        self.thresholdLambdaLineEdit.setProperty("value", 100000)
        self.thresholdLambdaLineEdit.setObjectName("thresholdLambdaLineEdit")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.thresholdLambdaLineEdit)
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fitInterceptCheckBox.setChecked(True)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.copyXLabel = QtWidgets.QLabel(self.formGroupBox)
        self.copyXLabel.setObjectName("copyXLabel")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.copyXLabel)
        self.copyXCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.copyXCheckBox.setChecked(True)
        self.copyXCheckBox.setObjectName("copyXCheckBox")
        self.formLayout.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.copyXCheckBox)
        self.verboseLabel = QtWidgets.QLabel(self.formGroupBox)
        self.verboseLabel.setObjectName("verboseLabel")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.LabelRole, self.verboseLabel)
        self.verboseCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.verboseCheckBox.setObjectName("verboseCheckBox")
        self.formLayout.setWidget(11, QtWidgets.QFormLayout.FieldRole, self.verboseCheckBox)
        self.lambdaLabel_2 = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel_2.setObjectName("lambdaLabel_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel_2)
        self.lambdaLineEdit_2 = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambdaLineEdit_2.setProperty("decimals", 8)
        self.lambdaLineEdit_2.setProperty("singleStep", 1e-06)
        self.lambdaLineEdit_2.setProperty("value", 1e-06)
        self.lambdaLineEdit_2.setObjectName("lambdaLineEdit_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lambdaLineEdit_2)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.numOfIterationsLineEdit, self.toleranceLineEdit)
        Form.setTabOrder(self.toleranceLineEdit, self.alpha1LineEdit)
        Form.setTabOrder(self.alpha1LineEdit, self.alpha2LineEdit)
        Form.setTabOrder(self.alpha2LineEdit, self.lambdaLineEdit)
        Form.setTabOrder(self.lambdaLineEdit, self.lambdaLineEdit_2)
        Form.setTabOrder(self.lambdaLineEdit_2, self.computerScoreCheckBox)
        Form.setTabOrder(self.computerScoreCheckBox, self.thresholdLambdaLineEdit)
        Form.setTabOrder(self.thresholdLambdaLineEdit, self.fitInterceptCheckBox)
        Form.setTabOrder(self.fitInterceptCheckBox, self.normalizeCheckBox)
        Form.setTabOrder(self.normalizeCheckBox, self.copyXCheckBox)
        Form.setTabOrder(self.copyXCheckBox, self.verboseCheckBox)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.numOfIterationsLabel.setText(("num of iterations"))
        self.toleranceLabel.setText(("Tolerance"))
        self.alpha1Label.setText(("Alpha 1"))
        self.alpha2Label.setText(("Alpha 2"))
        self.lambdaLabel.setText(("Lambda 1"))
        self.computerScoreLabel.setText(("Computer Score"))
        self.computerScoreCheckBox.setText(("compute the objective function at each step of the model"))
        self.thresholdLambdaLabel.setText(("Threshold Lambda"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.fitInterceptCheckBox.setText(("calculate the intercept for this model"))
        self.normalizeLabel.setText(("Normalize"))
        self.normalizeCheckBox.setText(("regressors X will be normlized before regression"))
        self.copyXLabel.setText(("Copy X"))
        self.copyXCheckBox.setText(("X will be copied; else, it may be overwritten"))
        self.verboseLabel.setText(("Verbose"))
        self.verboseCheckBox.setText(("Verbose mode when fitting the model"))
        self.lambdaLabel_2.setText(("Lambda 2"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.horizontalLayout_5.addWidget(self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.horizontalLayout_5.addWidget(self.chooseDataComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_5, 0, 0, 1, 1)
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.chooseMethodLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseMethodLabel.setObjectName("chooseMethodLabel")
        self.horizontalLayout_4.addWidget(self.chooseMethodLabel)
        self.chooseMethodComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseMethodComboBox.setObjectName("chooseMethodComboBox")
        self.horizontalLayout_4.addWidget(self.chooseMethodComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_4, 1, 0, 1, 1)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.chooseXVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseXVariableLabel.setObjectName("chooseXVariableLabel")
        self.horizontalLayout_3.addWidget(self.chooseXVariableLabel)
        self.chooseXVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseXVariableComboBox.setObjectName("chooseXVariableComboBox")
        self.horizontalLayout_3.addWidget(self.chooseXVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_3, 2, 0, 1, 1)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.chooseYVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseYVariableLabel.setObjectName("chooseYVariableLabel")
        self.horizontalLayout_2.addWidget(self.chooseYVariableLabel)
        self.chooseYVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseYVariableComboBox.setObjectName("chooseYVariableComboBox")
        self.horizontalLayout_2.addWidget(self.chooseYVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout_2, 2, 1, 1, 1)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.colorCodedVariableLabel = QtWidgets.QLabel(self.groupBox)
        self.colorCodedVariableLabel.setMaximumSize(QtCore.QSize(16777215, 10))
        self.colorCodedVariableLabel.setObjectName("colorCodedVariableLabel")
        self.horizontalLayout.addWidget(self.colorCodedVariableLabel)
        self.colorCodedVariableComboBox = QtWidgets.QComboBox(self.groupBox)
        self.colorCodedVariableComboBox.setObjectName("colorCodedVariableComboBox")
        self.horizontalLayout.addWidget(self.colorCodedVariableComboBox)
        self.gridLayout.addLayout(self.horizontalLayout, 3, 0, 1, 2)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.plotFilenameLabel = QtWidgets.QLabel(self.groupBox)
        self.plotFilenameLabel.setObjectName("plotFilenameLabel")
        self.horizontalLayout_6.addWidget(self.plotFilenameLabel)
        self.plotFilenameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.plotFilenameLineEdit.setReadOnly(True)
        self.plotFilenameLineEdit.setObjectName("plotFilenameLineEdit")
        self.horizontalLayout_6.addWidget(self.plotFilenameLineEdit)
        self.pushButton = QtWidgets.QPushButton(self.groupBox)
        self.pushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout_6.addWidget(self.pushButton)
        self.gridLayout.addLayout(self.horizontalLayout_6, 4, 0, 1, 2)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.chooseDataComboBox, self.chooseMethodComboBox)
        Form.setTabOrder(self.chooseMethodComboBox, self.chooseXVariableComboBox)
        Form.setTabOrder(self.chooseXVariableComboBox, self.chooseYVariableComboBox)
        Form.setTabOrder(self.chooseYVariableComboBox, self.colorCodedVariableComboBox)
        Form.setTabOrder(self.colorCodedVariableComboBox, self.plotFilenameLineEdit)
        Form.setTabOrder(self.plotFilenameLineEdit, self.pushButton)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Plot ICA/PCA"))
        self.chooseDataLabel.setText(("Choose data"))
        self.chooseMethodLabel.setText(("Choose method"))
        self.chooseXVariableLabel.setText(("Choose X Variable"))
        self.chooseYVariableLabel.setText(("Choose Y Variable"))
        self.colorCodedVariableLabel.setText(("Choose variable to color code points (optional)"))
        self.plotFilenameLabel.setText(("Plot Filename"))
        self.pushButton.setText(("..."))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets

from point_spectra_gui.ui.OutputFolder import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class OutputFolder(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def on_outPutLocationButton_clicked(self):
        filename = QtWidgets.QFileDialog.getExistingDirectory(None, "Select Output Directory", '.')
        self.folderNameLineEdit.setText(filename)
        if self.folderNameLineEdit.text() == "":
            self.folderNameLineEdit.setText("*/")

    def connectWidgets(self):
        pass

        self.pushButton.clicked.connect(lambda: self.on_outPutLocationButton_clicked())

    def function(self):
        params = self.getGuiParams()
        outpath = params['folderNameLineEdit']
        try:
            Basics.outpath = outpath
            print("Output path folder has been set to " + outpath)
        except Exception as e:
            print("Error: {}; using default outpath: {}".format(e, Basics.outpath))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = OutputFolder()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from point_spectra_gui.core.crossValidateMethods import cv_ARD
from point_spectra_gui.core.crossValidateMethods import cv_BayesianRidge
from point_spectra_gui.core.crossValidateMethods import cv_ElasticNet
from point_spectra_gui.core.crossValidateMethods import cv_GP
from point_spectra_gui.core.crossValidateMethods import cv_KRR
from point_spectra_gui.core.crossValidateMethods import cv_LARS
from point_spectra_gui.core.crossValidateMethods import cv_Lasso
from point_spectra_gui.core.crossValidateMethods import cv_LassoLARS
from point_spectra_gui.core.crossValidateMethods import cv_OLS
from point_spectra_gui.core.crossValidateMethods import cv_OMP
from point_spectra_gui.core.crossValidateMethods import cv_PLS
from point_spectra_gui.core.crossValidateMethods import cv_Ridge
from point_spectra_gui.core.crossValidateMethods import cv_SVR



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.chooseDataToStratifyLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseDataToStratifyLabel.setObjectName("chooseDataToStratifyLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseDataToStratifyLabel)
        self.chooseDataToStratifyComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseDataToStratifyComboBox.setObjectName("chooseDataToStratifyComboBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseDataToStratifyComboBox)
        self.chooseVarLabel = QtWidgets.QLabel(self.formGroupBox)
        self.chooseVarLabel.setObjectName("chooseVarLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.chooseVarLabel)
        self.chooseVarComboBox = QtWidgets.QComboBox(self.formGroupBox)
        self.chooseVarComboBox.setObjectName("chooseVarComboBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.chooseVarComboBox)
        self.nFoldsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.nFoldsLabel.setObjectName("nFoldsLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nFoldsLabel)
        self.nFoldsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.nFoldsSpinBox.setObjectName("nFoldsSpinBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.nFoldsSpinBox)
        self.testFoldsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.testFoldsLabel.setObjectName("testFoldsLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.testFoldsLabel)
        self.testFoldsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.testFoldsSpinBox.setObjectName("testFoldsSpinBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.testFoldsSpinBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("Stratified Folds"))
        self.chooseDataToStratifyLabel.setText(("Choose data to stratify: "))
        self.chooseVarLabel.setText(("Choose variable on which to sort: "))
        self.nFoldsLabel.setText(("N Folds"))
        self.testFoldsLabel.setText(("Test Fold"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from pysat.spectral.baseline_code.ccam_remove_continuum import ccam_br

from point_spectra_gui.ui.CCAM import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        CCAM = ccam_br()
        self.lowestWaveletScaleSpinBox.setValue(CCAM.lvmin_)
        self.largestWaveletScaleSpinBox.setValue(CCAM.lv_)

    def function(self):
        methodParameters = {'lv_': int(self.largestWaveletScaleSpinBox.value()),
                            'lvmin_': int(self.lowestWaveletScaleSpinBox.value())}

        int_flag = self.interpolationMethodComboBox.currentText()
        if int_flag == 'Linear':
            methodParameters.update({'int_flag_': 0})
        elif int_flag == 'Quadratic':
            methodParameters.update({'int_flag_': 1})
        elif int_flag == 'Spline':
            methodParameters.update({'int_flag_': 2})

        return methodParameters


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import numpy as np
from PyQt5 import QtWidgets
from pysat.spectral.spectral_data import spectral_data

from point_spectra_gui.ui.SplitDataset import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class SplitDataset(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        try:
            self.setComboBox(self.chooseDataComboBox, self.datakeys)
            self.setComboBox(self.splitOnUniqueValuesOfComboBox, self.get_choices())
        except:
            pass

    def function(self):
        datakey = self.chooseDataComboBox.currentText()
        colname = self.splitOnUniqueValuesOfComboBox.currentText()
        vars_level0 = self.data[datakey].df.columns.get_level_values(0)
        vars_level1 = self.data[datakey].df.columns.get_level_values(1)
        vars_level1 = list(vars_level1[vars_level0 != 'wvl'])
        vars_level0 = list(vars_level0[vars_level0 != 'wvl'])
        colname = (vars_level0[vars_level1.index(colname)], colname)

        coldata = np.array([str(i) for i in self.data[datakey].df[colname]])
        unique_values = np.unique(coldata)
        for i in unique_values:
            new_datakey = datakey + ' - ' + str(i)
            self.datakeys.append(new_datakey)
            self.data[new_datakey] = spectral_data(self.data[datakey].df.ix[coldata == i])

    def get_choices(self):
        try:
            self.vars_level0 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = list(self.vars_level1[self.vars_level0 != 'wvl'])
            self.vars_level0 = list(self.vars_level0[self.vars_level0 != 'wvl'])
            colnamechoices = self.vars_level1
            return colnamechoices
        except:
            try:
                colnamechoices = self.data[self.chooseDataComboBox.currentText()].columns.values
                colnamechoices = [i for i in colnamechoices if
                                  not 'Unnamed' in i]  # remove unnamed columns from choices
                return colnamechoices
            except:
                pass


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = SplitDataset()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import sys


def my_exception_hook(exctype, value, traceback):
    # Print the error and traceback
    print(exctype, value, traceback)
    # Call the normal Exception hook after
    sys._excepthook(exctype, value, traceback)
    sys.exit(1)




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.alphaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.alphaLabel.setObjectName("alphaLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.alphaLabel)
        self.alphaSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.alphaSpinBox.setObjectName("alphaSpinBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.alphaSpinBox)
        self.kernelLabel = QtWidgets.QLabel(self.formGroupBox)
        self.kernelLabel.setObjectName("kernelLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.kernelLabel)
        self.kernelLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.kernelLineEdit.setObjectName("kernelLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.kernelLineEdit)
        self.gammaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.gammaLabel.setObjectName("gammaLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.gammaLabel)
        self.gammaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.gammaLineEdit.setObjectName("gammaLineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.gammaLineEdit)
        self.degreeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.degreeLabel.setObjectName("degreeLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.degreeLabel)
        self.degreeDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.degreeDoubleSpinBox.setMaximum(9999999.0)
        self.degreeDoubleSpinBox.setProperty("value", 3.0)
        self.degreeDoubleSpinBox.setObjectName("degreeDoubleSpinBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.degreeDoubleSpinBox)
        self.coeff0Label = QtWidgets.QLabel(self.formGroupBox)
        self.coeff0Label.setObjectName("coeff0Label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.coeff0Label)
        self.coeff0DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.coeff0DoubleSpinBox.setMaximum(9999999.0)
        self.coeff0DoubleSpinBox.setProperty("value", 1.0)
        self.coeff0DoubleSpinBox.setObjectName("coeff0DoubleSpinBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.coeff0DoubleSpinBox)
        self.kernelParametersLabel = QtWidgets.QLabel(self.formGroupBox)
        self.kernelParametersLabel.setObjectName("kernelParametersLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.kernelParametersLabel)
        self.kernelParametersLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.kernelParametersLineEdit.setObjectName("kernelParametersLineEdit")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.kernelParametersLineEdit)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.alphaLabel.setText(("Alpha"))
        self.kernelLabel.setText(("Kernel"))
        self.kernelLineEdit.setText(("linear"))
        self.gammaLabel.setText(("Gamma"))
        self.gammaLineEdit.setText(("None"))
        self.degreeLabel.setText(("Degree"))
        self.coeff0Label.setText(("Coeff 0"))
        self.kernelParametersLabel.setText(("Kernel Parameters"))
        self.kernelParametersLineEdit.setText(("None"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from pysat.spectral.baseline_code.als import ALS

from point_spectra_gui.ui.ALS import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        als = ALS()

        self.asymmetryDoubleSpinBox.setDecimals(2)
        self.smoothnessDoubleSpinBox.setMaximum(10000000)
        self.convergenceThresholdDoubleSpinBox.setDecimals(6)

        self.asymmetryDoubleSpinBox.setValue(als.asymmetry_)
        self.smoothnessDoubleSpinBox.setValue(als.smoothness_)
        self.maxNumOfIterationsSpinBox.setValue(als.max_iters_)
        self.convergenceThresholdDoubleSpinBox.setValue(als.conv_thresh_)

    def function(self):
        methodParameters = {'asymmetry_': float(self.asymmetryDoubleSpinBox.value()),
                            'smoothness_': float(self.smoothnessDoubleSpinBox.value()),
                            'max_iters_': int(self.maxNumOfIterationsSpinBox.value()),
                            'conv_thresh_': float(self.convergenceThresholdDoubleSpinBox.value())}
        return methodParameters


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.searchStringLabel = QtWidgets.QLabel(self.groupBox)
        self.searchStringLabel.setObjectName("searchStringLabel")
        self.gridLayout.addWidget(self.searchStringLabel, 0, 0, 1, 1)
        self.searchStringLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.searchStringLineEdit.setObjectName("searchStringLineEdit")
        self.gridLayout.addWidget(self.searchStringLineEdit, 0, 1, 1, 1)
        self.searchDirectoryLabel = QtWidgets.QLabel(self.groupBox)
        self.searchDirectoryLabel.setObjectName("searchDirectoryLabel")
        self.gridLayout.addWidget(self.searchDirectoryLabel, 1, 0, 1, 1)
        self.searchDirectoryLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.searchDirectoryLineEdit.setObjectName("searchDirectoryLineEdit")
        self.gridLayout.addWidget(self.searchDirectoryLineEdit, 1, 1, 1, 1)
        self.searchDirectorypushButton = QtWidgets.QPushButton(self.groupBox)
        self.searchDirectorypushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.searchDirectorypushButton.setObjectName("searchDirectorypushButton")
        self.gridLayout.addWidget(self.searchDirectorypushButton, 1, 2, 1, 1)
        self.metadataFilesLabel = QtWidgets.QLabel(self.groupBox)
        self.metadataFilesLabel.setObjectName("metadataFilesLabel")
        self.gridLayout.addWidget(self.metadataFilesLabel, 2, 0, 1, 1)
        self.metadataFilesLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.metadataFilesLineEdit.setObjectName("metadataFilesLineEdit")
        self.gridLayout.addWidget(self.metadataFilesLineEdit, 2, 1, 1, 1)
        self.metadatapushButton = QtWidgets.QPushButton(self.groupBox)
        self.metadatapushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.metadatapushButton.setObjectName("metadatapushButton")
        self.gridLayout.addWidget(self.metadatapushButton, 2, 2, 1, 1)
        self.outputFileNameLabel = QtWidgets.QLabel(self.groupBox)
        self.outputFileNameLabel.setObjectName("outputFileNameLabel")
        self.gridLayout.addWidget(self.outputFileNameLabel, 3, 0, 1, 1)
        self.outputFileNameLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.outputFileNameLineEdit.setObjectName("outputFileNameLineEdit")
        self.gridLayout.addWidget(self.outputFileNameLineEdit, 3, 1, 1, 1)
        self.averagesLabel = QtWidgets.QLabel(self.groupBox)
        self.averagesLabel.setObjectName("averagesLabel")
        self.gridLayout.addWidget(self.averagesLabel, 4, 0, 1, 1)
        self.averagesradioButton = QtWidgets.QRadioButton(self.groupBox)
        self.averagesradioButton.setText("")
        self.averagesradioButton.setChecked(True)
        self.averagesradioButton.setObjectName("averagesradioButton")
        self.gridLayout.addWidget(self.averagesradioButton, 4, 1, 1, 1)
        self.singleShotsLabel = QtWidgets.QLabel(self.groupBox)
        self.singleShotsLabel.setObjectName("singleShotsLabel")
        self.gridLayout.addWidget(self.singleShotsLabel, 5, 0, 1, 1)
        self.singleShotsradioButton = QtWidgets.QRadioButton(self.groupBox)
        self.singleShotsradioButton.setText("")
        self.singleShotsradioButton.setObjectName("singleShotsradioButton")
        self.gridLayout.addWidget(self.singleShotsradioButton, 5, 1, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Read ChemCam Data"))
        self.searchStringLabel.setText(("Search String:"))
        self.searchDirectoryLabel.setText(("Search directory:"))
        self.searchDirectorypushButton.setText(("..."))
        self.metadataFilesLabel.setText(("Metadata file(s):"))
        self.metadatapushButton.setText(("..."))
        self.outputFileNameLabel.setText(("Output file name:"))
        self.averagesLabel.setText(("Averages"))
        self.singleShotsLabel.setText(("Single Shots"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from pysat.regression import sm

from point_spectra_gui.ui.SubmodelPredict import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class subWidgets:
    def __init__(self, modelComboBox, minLabel, minSpinBox, maxLabel, maxSpinBox):
        self.modelComboBox = modelComboBox
        self.minLabel = minLabel
        self.minSpinBox = minSpinBox
        self.maxLabel = maxLabel
        self.maxSpinBox = maxSpinBox

    def get_modelComboBox(self):
        return self.modelComboBox

    def get_minSpinBox(self):
        return self.minSpinBox

    def get_maxSpinBox(self):
        return self.maxSpinBox

    def setHidden(self, bool):
        self.modelComboBox.setHidden(bool)
        self.minLabel.setHidden(bool)
        self.minSpinBox.setHidden(bool)
        self.maxLabel.setHidden(bool)
        self.maxSpinBox.setHidden(bool)

    def getValues(self):
        return [self.modelComboBox.currentText(), [int(self.minSpinBox.value()), int(self.maxSpinBox.value())]]

    def setMaximum(self, int_):
        self.minSpinBox.setMaximum(int_)
        self.maxSpinBox.setMaximum(int_)

    def setValue(self, int_):
        self.minSpinBox.setValue(int_)
        self.maxSpinBox.setValue(int_)

    def spinBox(self, int_):
        if int_ == 0:
            return self.minSpinBox
        elif int_ == 1:
            return self.maxSpinBox
        else:
            return "Not a valid number"


class SubmodelPredict(Ui_Form, Basics):
    def __init__(self):
        super().__init__()
        self.subwidgets = []
        self.index = 1

    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.referenceModelComboBox, self.modelkeys)
        self.setComboBox(self.lowModelComboBox, self.modelkeys)
        self.setComboBox(self.highModelComboBox, self.modelkeys)
        self.setComboBox(self.optimizeSubmodelRangesComboBox, self.datakeys)
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.addSubModelPushButton.clicked.connect(self.on_addRange_pushed)
        self.deleteSubModelPushButton.clicked.connect(self.on_deleteRange_pushed)
        self.setupWidgets()
        self.optimizeSubmodelRangesLabel.setHidden(True)
        self.optimizeSubmodelRangesComboBox.setHidden(True)
        self.setHidden(self.subwidgets)

    def setHidden(self, list):
        for i in range(0, len(list)):
            list[i].setHidden(True)

    def function(self):
        blendranges = []
        submodel_names = []
        x_ref = []
        x = []
        submodels = []

        # TODO there are some inefficiencies with this code:103:111
        # For example you are running through the UI to collect the data
        # And then running through the data to collect more data
        # You're doing this with seperate for loops. this could be done
        # with just one for loop. Example lines 103 and 111.
        self.submodel_gui_info = [[self.lowModelComboBox.currentText(), [-9999, int(self.lowModelMaxSpinBox.value())]]]
        for i in range(1, self.index):
            self.submodel_gui_info.append(self.subwidgets[i].getValues())
        self.submodel_gui_info.append(
            [self.highModelComboBox.currentText(), [int(self.highModelMinSpinBox.value()), 9999]])
        self.submodel_gui_info.append([self.referenceModelComboBox.currentText(), [-9999, 9999]])

        datakey = self.chooseDataComboBox.currentText()

        for sub_gui in self.submodel_gui_info:
            min_temp = sub_gui[1][0]
            max_temp = sub_gui[1][1]
            blendranges.append([min_temp, max_temp])
            submodel_names.append(sub_gui[0])

        if self.optimizeSubmodelRangesCheckBox.isChecked():
            trueval_data = self.optimizeSubmodelRangesComboBox.currentText()
        else:
            trueval_data = None

        # Check if reference data name has been provided
        # if so, get reference data values
        if trueval_data is not None:
            truevals = self.data[trueval_data].df[self.model_yvars[submodel_names[0]]]
        else:
            truevals = None

        # step through the submodel names and get the actual models and the x data
        for i in submodel_names:
            x.append(self.data[datakey].df[self.model_xvars[i]])
            submodels.append(self.models[i])
            if trueval_data is not None:
                x_ref.append(self.data[trueval_data].df[self.model_xvars[i]])

        # create the submodel object
        sm_obj = sm.sm(blendranges, submodels)

        # optimize blending if reference data is provided (otherwise, modelranges will be used as blending ranges)
        if truevals is not None:
            ref_predictions = sm_obj.predict(x_ref)
            ref_predictions_blended = sm_obj.do_blend(ref_predictions, truevals=truevals)

        # get predictions for each submodel separately
        predictions = sm_obj.predict(x)

        # blend the predictions together
        predictions_blended = sm_obj.do_blend(predictions)

        # save the individual and blended predictions
        for i, j in enumerate(predictions):
            self.data[datakey].df[('predict', submodel_names[i] + '-Predict')] = j
        self.data[datakey].df[('predict', 'Blended-Predict')] = predictions_blended

    def on_addRange_pushed(self):
        if self.index < len(self.subwidgets):
            self.subwidgets[self.index].setHidden(False)
            self.setComboBox(self.subwidgets[self.index].get_modelComboBox(), self.modelkeys)
            self.index += 1
        else:
            print("Cannot add more wavelengths")

    def on_deleteRange_pushed(self):
        if self.index > 1:
            self.index -= 1
            self.subwidgets[self.index].setHidden(True)
            self.subwidgets[self.index].setValue(0)
        else:
            print("Cannot delete any more wavelengths")

    def setupWidgets(self):
        self.subwidgets.append(
            subWidgets(self.modelComboBox, self.minLabel, self.minSpinBox, self.maxLabel, self.maxSpinBox))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_2, self.minLabel_2, self.minSpinBox_2, self.maxLabel_2, self.maxSpinBox_2))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_3, self.minLabel_3, self.minSpinBox_3, self.maxLabel_3, self.maxSpinBox_3))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_4, self.minLabel_4, self.minSpinBox_4, self.maxLabel_4, self.maxSpinBox_4))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_5, self.minLabel_5, self.minSpinBox_5, self.maxLabel_5, self.maxSpinBox_5))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_6, self.minLabel_6, self.minSpinBox_6, self.maxLabel_6, self.maxSpinBox_6))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_7, self.minLabel_7, self.minSpinBox_7, self.maxLabel_7, self.maxSpinBox_7))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_8, self.minLabel_8, self.minSpinBox_8, self.maxLabel_8, self.maxSpinBox_8))
        self.subwidgets.append(
            subWidgets(self.modelComboBox_9, self.minLabel_9, self.minSpinBox_9, self.maxLabel_9, self.maxSpinBox_9))
        self.subwidgets.append(subWidgets(self.modelComboBox_10, self.minLabel_10, self.minSpinBox_10, self.maxLabel_10,
                                          self.maxSpinBox_10))
        self.subwidgets.append(subWidgets(self.modelComboBox_11, self.minLabel_11, self.minSpinBox_11, self.maxLabel_11,
                                          self.maxSpinBox_11))
        self.subwidgets.append(subWidgets(self.modelComboBox_12, self.minLabel_12, self.minSpinBox_12, self.maxLabel_12,
                                          self.maxSpinBox_12))
        self.subwidgets.append(subWidgets(self.modelComboBox_13, self.minLabel_13, self.minSpinBox_13, self.maxLabel_13,
                                          self.maxSpinBox_13))
        self.subwidgets.append(subWidgets(self.modelComboBox_14, self.minLabel_14, self.minSpinBox_14, self.maxLabel_14,
                                          self.maxSpinBox_14))
        self.subwidgets.append(subWidgets(self.modelComboBox_15, self.minLabel_15, self.minSpinBox_15, self.maxLabel_15,
                                          self.maxSpinBox_15))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = SubmodelPredict()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.ENLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.ENLayout.setObjectName("ENLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.elasticNetCVGroupBox = QtWidgets.QGroupBox(self.groupBox)
        self.elasticNetCVGroupBox.setObjectName("elasticNetCVGroupBox")
        self.ElasticNetCV_2 = QtWidgets.QFormLayout(self.elasticNetCVGroupBox)
        self.ElasticNetCV_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.ElasticNetCV_2.setObjectName("ElasticNetCV_2")
        self.l1_ratioLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.l1_ratioLabel.setObjectName("l1_ratioLabel")
        self.ElasticNetCV_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.l1_ratioLabel)
        self.l1_ratioDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetCVGroupBox)
        self.l1_ratioDoubleSpinBox.setObjectName("l1_ratioDoubleSpinBox")
        self.ElasticNetCV_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.l1_ratioDoubleSpinBox)
        self.epsLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.epsLabel.setObjectName("epsLabel")
        self.ElasticNetCV_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.epsLabel)
        self.epsDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetCVGroupBox)
        self.epsDoubleSpinBox.setObjectName("epsDoubleSpinBox")
        self.ElasticNetCV_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.epsDoubleSpinBox)
        self.n_alphasLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.n_alphasLabel.setObjectName("n_alphasLabel")
        self.ElasticNetCV_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.n_alphasLabel)
        self.n_alphasSpinBox = QtWidgets.QSpinBox(self.elasticNetCVGroupBox)
        self.n_alphasSpinBox.setObjectName("n_alphasSpinBox")
        self.ElasticNetCV_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.n_alphasSpinBox)
        self.alphasLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.alphasLabel.setObjectName("alphasLabel")
        self.ElasticNetCV_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.alphasLabel)
        self.alphasLineEdit = QtWidgets.QLineEdit(self.elasticNetCVGroupBox)
        self.alphasLineEdit.setObjectName("alphasLineEdit")
        self.ElasticNetCV_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.alphasLineEdit)
        self.fit_interceptLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.fit_interceptLabel.setObjectName("fit_interceptLabel")
        self.ElasticNetCV_2.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.fit_interceptLabel)
        self.fit_interceptCheckBox = QtWidgets.QCheckBox(self.elasticNetCVGroupBox)
        self.fit_interceptCheckBox.setObjectName("fit_interceptCheckBox")
        self.ElasticNetCV_2.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.fit_interceptCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.ElasticNetCV_2.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.elasticNetCVGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.ElasticNetCV_2.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.precomputeLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.precomputeLabel.setObjectName("precomputeLabel")
        self.ElasticNetCV_2.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.precomputeLabel)
        self.precomputeComboBox = QtWidgets.QComboBox(self.elasticNetCVGroupBox)
        self.precomputeComboBox.setObjectName("precomputeComboBox")
        self.ElasticNetCV_2.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.precomputeComboBox)
        self.max_iterLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.max_iterLabel.setObjectName("max_iterLabel")
        self.ElasticNetCV_2.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.max_iterLabel)
        self.max_iterSpinBox = QtWidgets.QSpinBox(self.elasticNetCVGroupBox)
        self.max_iterSpinBox.setObjectName("max_iterSpinBox")
        self.ElasticNetCV_2.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.max_iterSpinBox)
        self.tolLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.tolLabel.setObjectName("tolLabel")
        self.ElasticNetCV_2.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.tolLabel)
        self.tolDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetCVGroupBox)
        self.tolDoubleSpinBox.setObjectName("tolDoubleSpinBox")
        self.ElasticNetCV_2.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.tolDoubleSpinBox)
        self.copy_XLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.copy_XLabel.setObjectName("copy_XLabel")
        self.ElasticNetCV_2.setWidget(11, QtWidgets.QFormLayout.LabelRole, self.copy_XLabel)
        self.copy_XCheckBox = QtWidgets.QCheckBox(self.elasticNetCVGroupBox)
        self.copy_XCheckBox.setObjectName("copy_XCheckBox")
        self.ElasticNetCV_2.setWidget(11, QtWidgets.QFormLayout.FieldRole, self.copy_XCheckBox)
        self.verboseLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.verboseLabel.setObjectName("verboseLabel")
        self.ElasticNetCV_2.setWidget(12, QtWidgets.QFormLayout.LabelRole, self.verboseLabel)
        self.verboseCheckBox = QtWidgets.QCheckBox(self.elasticNetCVGroupBox)
        self.verboseCheckBox.setObjectName("verboseCheckBox")
        self.ElasticNetCV_2.setWidget(12, QtWidgets.QFormLayout.FieldRole, self.verboseCheckBox)
        self.n_jobsLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.n_jobsLabel.setObjectName("n_jobsLabel")
        self.ElasticNetCV_2.setWidget(13, QtWidgets.QFormLayout.LabelRole, self.n_jobsLabel)
        self.n_jobsSpinBox = QtWidgets.QSpinBox(self.elasticNetCVGroupBox)
        self.n_jobsSpinBox.setObjectName("n_jobsSpinBox")
        self.ElasticNetCV_2.setWidget(13, QtWidgets.QFormLayout.FieldRole, self.n_jobsSpinBox)
        self.positiveLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.positiveLabel.setObjectName("positiveLabel")
        self.ElasticNetCV_2.setWidget(14, QtWidgets.QFormLayout.LabelRole, self.positiveLabel)
        self.positiveCheckBox = QtWidgets.QCheckBox(self.elasticNetCVGroupBox)
        self.positiveCheckBox.setObjectName("positiveCheckBox")
        self.ElasticNetCV_2.setWidget(14, QtWidgets.QFormLayout.FieldRole, self.positiveCheckBox)
        self.selectionLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.selectionLabel.setObjectName("selectionLabel")
        self.ElasticNetCV_2.setWidget(15, QtWidgets.QFormLayout.LabelRole, self.selectionLabel)
        self.selectionComboBox = QtWidgets.QComboBox(self.elasticNetCVGroupBox)
        self.selectionComboBox.setObjectName("selectionComboBox")
        self.ElasticNetCV_2.setWidget(15, QtWidgets.QFormLayout.FieldRole, self.selectionComboBox)
        self.cVLabel = QtWidgets.QLabel(self.elasticNetCVGroupBox)
        self.cVLabel.setObjectName("cVLabel")
        self.ElasticNetCV_2.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.cVLabel)
        self.cVSpinBox = QtWidgets.QSpinBox(self.elasticNetCVGroupBox)
        self.cVSpinBox.setObjectName("cVSpinBox")
        self.ElasticNetCV_2.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.cVSpinBox)
        self.horizontalLayout.addWidget(self.elasticNetCVGroupBox)
        self.elasticNetGroupBox = QtWidgets.QGroupBox(self.groupBox)
        self.elasticNetGroupBox.setObjectName("elasticNetGroupBox")
        self.ElasticNet = QtWidgets.QFormLayout(self.elasticNetGroupBox)
        self.ElasticNet.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.ElasticNet.setObjectName("ElasticNet")
        self.enalphaLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enalphaLabel.setObjectName("enalphaLabel")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.enalphaLabel)
        self.enalphaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.enalphaDoubleSpinBox.setObjectName("enalphaDoubleSpinBox")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.enalphaDoubleSpinBox)
        self.enl1_ratioLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enl1_ratioLabel.setObjectName("enl1_ratioLabel")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.enl1_ratioLabel)
        self.enl1_ratioDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.enl1_ratioDoubleSpinBox.setObjectName("enl1_ratioDoubleSpinBox")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.enl1_ratioDoubleSpinBox)
        self.enfit_interceptLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enfit_interceptLabel.setObjectName("enfit_interceptLabel")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.enfit_interceptLabel)
        self.enfit_interceptCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enfit_interceptCheckBox.setObjectName("enfit_interceptCheckBox")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.enfit_interceptCheckBox)
        self.ennormalizeLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.ennormalizeLabel.setObjectName("ennormalizeLabel")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.ennormalizeLabel)
        self.ennormalizeCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.ennormalizeCheckBox.setObjectName("ennormalizeCheckBox")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.ennormalizeCheckBox)
        self.enprecomputeLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enprecomputeLabel.setObjectName("enprecomputeLabel")
        self.ElasticNet.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.enprecomputeLabel)
        self.enprecomputeCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enprecomputeCheckBox.setObjectName("enprecomputeCheckBox")
        self.ElasticNet.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.enprecomputeCheckBox)
        self.enmax_iterLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enmax_iterLabel.setObjectName("enmax_iterLabel")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.enmax_iterLabel)
        self.enmax_iterSpinBox = QtWidgets.QSpinBox(self.elasticNetGroupBox)
        self.enmax_iterSpinBox.setObjectName("enmax_iterSpinBox")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.enmax_iterSpinBox)
        self.encopy_XLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.encopy_XLabel.setObjectName("encopy_XLabel")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.encopy_XLabel)
        self.encopy_XCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.encopy_XCheckBox.setObjectName("encopy_XCheckBox")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.encopy_XCheckBox)
        self.entolLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.entolLabel.setObjectName("entolLabel")
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.entolLabel)
        self.entolDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.entolDoubleSpinBox.setObjectName("entolDoubleSpinBox")
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.entolDoubleSpinBox)
        self.enwarm_startLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enwarm_startLabel.setObjectName("enwarm_startLabel")
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.enwarm_startLabel)
        self.enwarm_startCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enwarm_startCheckBox.setObjectName("enwarm_startCheckBox")
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.enwarm_startCheckBox)
        self.enpositiveLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enpositiveLabel.setObjectName("enpositiveLabel")
        self.ElasticNet.setWidget(9, QtWidgets.QFormLayout.LabelRole, self.enpositiveLabel)
        self.enpositiveCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enpositiveCheckBox.setObjectName("enpositiveCheckBox")
        self.ElasticNet.setWidget(9, QtWidgets.QFormLayout.FieldRole, self.enpositiveCheckBox)
        self.enselectionLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enselectionLabel.setObjectName("enselectionLabel")
        self.ElasticNet.setWidget(10, QtWidgets.QFormLayout.LabelRole, self.enselectionLabel)
        self.enselectionComboBox = QtWidgets.QComboBox(self.elasticNetGroupBox)
        self.enselectionComboBox.setObjectName("enselectionComboBox")
        self.enselectionComboBox.addItem("")
        self.enselectionComboBox.addItem("")
        self.ElasticNet.setWidget(10, QtWidgets.QFormLayout.FieldRole, self.enselectionComboBox)
        self.horizontalLayout.addWidget(self.elasticNetGroupBox)
        self.ENLayout.addLayout(self.horizontalLayout)
        self.CVCheckBox = QtWidgets.QCheckBox(self.groupBox)
        self.CVCheckBox.setObjectName("CVCheckBox")
        self.ENLayout.addWidget(self.CVCheckBox)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        self.CVCheckBox.toggled['bool'].connect(self.elasticNetCVGroupBox.setVisible)
        self.CVCheckBox.toggled['bool'].connect(self.elasticNetGroupBox.setHidden)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.elasticNetCVGroupBox.setTitle(("Elastic Net CV"))
        self.l1_ratioLabel.setText(_translate("Form", "l1_ratio\n"
""))
        self.epsLabel.setText(_translate("Form", "eps\n"
""))
        self.n_alphasLabel.setText(_translate("Form", "n_alphas\n"
""))
        self.alphasLabel.setText(_translate("Form", "alphas\n"
""))
        self.fit_interceptLabel.setText(_translate("Form", "fit_intercept\n"
""))
        self.normalizeLabel.setText(_translate("Form", "normalize\n"
""))
        self.precomputeLabel.setText(_translate("Form", "precompute\n"
""))
        self.max_iterLabel.setText(_translate("Form", "max_iter\n"
""))
        self.tolLabel.setText(_translate("Form", "tol\n"
""))
        self.copy_XLabel.setText(_translate("Form", "copy_X\n"
""))
        self.verboseLabel.setText(_translate("Form", "verbose\n"
""))
        self.n_jobsLabel.setText(_translate("Form", "n_jobs\n"
""))
        self.positiveLabel.setText(_translate("Form", "positive\n"
""))
        self.selectionLabel.setText(("selection"))
        self.cVLabel.setText(("cv"))
        self.elasticNetGroupBox.setTitle(("Elastic Net"))
        self.enalphaLabel.setText(_translate("Form", "alpha\n"
""))
        self.enl1_ratioLabel.setText(_translate("Form", "l1_ratio\n"
""))
        self.enfit_interceptLabel.setText(_translate("Form", "fit_intercept\n"
""))
        self.ennormalizeLabel.setText(_translate("Form", "normalize\n"
""))
        self.enprecomputeLabel.setText(_translate("Form", "precompute\n"
""))
        self.enmax_iterLabel.setText(_translate("Form", "max_iter\n"
""))
        self.encopy_XLabel.setText(_translate("Form", "copy_X\n"
""))
        self.entolLabel.setText(_translate("Form", "tol\n"
""))
        self.enwarm_startLabel.setText(_translate("Form", "warm_start\n"
""))
        self.enpositiveLabel.setText(("positive"))
        self.enselectionLabel.setText(("selection"))
        self.enselectionComboBox.setItemText(0, ("cyclic"))
        self.enselectionComboBox.setItemText(1, ("random"))
        self.CVCheckBox.setText(("CV"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import numpy as np
from PyQt5 import QtWidgets
from pysat.plotting.plots import make_plot

from point_spectra_gui.ui.Plot import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Plot(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.figureNameComboBox, self.figname)
        self.changeComboListVars(self.chooseXVariableComboBox, self.get_choices())
        self.changeComboListVars(self.chooseYVariableComboBox, self.get_choices())
        self.colorComboBox.addItem("Red")
        self.colorComboBox.addItem("Green")
        self.colorComboBox.addItem("Blue")
        self.colorComboBox.addItem("Cyan")
        self.colorComboBox.addItem("Yellow")
        self.colorComboBox.addItem("Magenta")
        self.colorComboBox.addItem("Black")
        self.lineComboBox.addItem("No Line")
        self.lineComboBox.addItem("Line")
        self.lineComboBox.addItem("Dashed Line")
        self.lineComboBox.addItem("Dotted Line")
        self.markerComboBox.addItem("Circles")
        self.markerComboBox.addItem("Squares")
        self.markerComboBox.addItem("Diamonds")
        self.markerComboBox.addItem("Triangle Up")
        self.markerComboBox.addItem("Triangle Down")
        self.markerComboBox.addItem("Triangle Left")
        self.markerComboBox.addItem("Triangle Right")
        self.markerComboBox.addItem("None")
        self.alphaDoubleSpinBox.setValue(0.25)
        self.alphaDoubleSpinBox.setSingleStep(0.25)
        self.alphaDoubleSpinBox.setMaximum(1)
        self.xMinDoubleSpinBox.setMaximum(110)
        self.xMaxDoubleSpinBox.setMaximum(110)
        self.yMinDoubleSpinBox.setMaximum(110)
        self.yMaxDoubleSpinBox.setMaximum(110)
        self.plotFilenamePushButton.clicked.connect(self.on_plotFilenamePushButton_clicked)

        self.figureNameComboBox.activated[int].connect(
            lambda: self.figureNameLineEdit.setText(self.figureNameComboBox.currentText()))
        self.chooseDataComboBox.activated[int].connect(
            lambda: self.changeComboListVars(self.chooseXVariableComboBox, self.get_choices()))
        self.chooseDataComboBox.activated[int].connect(
            lambda: self.changeComboListVars(self.chooseYVariableComboBox, self.get_choices()))
        self.chooseDataComboBox.activated[int].connect(
            lambda: self.get_minmax(self.xMinDoubleSpinBox, self.xMaxDoubleSpinBox,
                                    self.chooseXVariableComboBox.currentText()))
        self.chooseDataComboBox.activated[int].connect(
            lambda: self.get_minmax(self.yMinDoubleSpinBox, self.yMaxDoubleSpinBox,
                                    self.chooseYVariableComboBox.currentText()))
        self.chooseXVariableComboBox.activated[int].connect(
            lambda: self.get_minmax(self.xMinDoubleSpinBox, self.xMaxDoubleSpinBox,
                                    self.chooseXVariableComboBox.currentText()))
        self.chooseYVariableComboBox.activated[int].connect(
            lambda: self.get_minmax(self.yMinDoubleSpinBox, self.yMaxDoubleSpinBox,
                                    self.chooseYVariableComboBox.currentText()))

    def function(self):

        datakey = self.chooseDataComboBox.currentText()
        xvar = self.chooseXVariableComboBox.currentText()
        yvar = self.chooseYVariableComboBox.currentText()

        figname = self.figureNameLineEdit.text()
        title = self.plotTitleLineEdit.text()
        xrange = self.xMinDoubleSpinBox.value(), self.xMaxDoubleSpinBox.value()
        yrange = self.yMinDoubleSpinBox.value(), self.yMaxDoubleSpinBox.value()
        xtitle = self.xTitleLineEdit.text()
        ytitle = self.yTitleLineEdit.text()
        lbl = self.legendLineEdit.text()
        one_to_one = self.oneToOneCheckBox.isChecked()

        color = self.colorComboBox.currentText()
        alpha = self.alphaDoubleSpinBox.value()
        annot_mask = None
        cmap = None
        colortitle = ''
        dpi = 1000

        if color == 'Red':
            color = [1, 0, 0, alpha]
        elif color == 'Green':
            color = [0, 1, 0, alpha]
        elif color == 'Blue':
            color = [0, 0, 1, alpha]
        elif color == 'Cyan':
            color = [0, 1, 1, alpha]
        elif color == 'Yellow':
            color = [1, 1, 0, alpha]
        elif color == 'Magenta':
            color = [1, 0, 1, alpha]
        elif color == 'Black':
            color = [0, 0, 0, alpha]

        marker = self.markerComboBox.currentText()
        if marker == 'Circles':
            marker = 'o'
        if marker == 'Squares':
            marker = 's'
        if marker == 'Diamonds':
            marker = 'D'
        if marker == 'Triangle Up':
            marker = '^'
        if marker == 'Triangle Down':
            marker = 'v'
        if marker == 'Triangle Right':
            marker = '>'
        if marker == 'Triangle Left':
            marker = '<'

        linestyle = self.lineComboBox.currentText()
        if linestyle == 'No Line':
            linestyle = 'None'
        if linestyle == 'Line':
            linestyle = '-'
        if linestyle == 'Dashed Line':
            linestyle = '--'
        if linestyle == 'Dotted Line':
            linestyle = ':'

        try:
            if self.data[datakey].df.columns.nlevels == 2:
                vars_level0 = self.data[datakey].df.columns.get_level_values(0)
                vars_level1 = self.data[datakey].df.columns.get_level_values(1)
                vars_level1 = list(vars_level1[vars_level0 != 'wvl'])
                vars_level0 = list(vars_level0[vars_level0 != 'wvl'])
                xvar = (vars_level0[vars_level1.index(xvar)], xvar)
                yvar = (vars_level0[vars_level1.index(yvar)], yvar)
        except AttributeError:  # df attribute doesn't exist.
            pass

        try:
            x = self.data[datakey].df[xvar]
            y = self.data[datakey].df[yvar]
        except:
            x = self.data[datakey]['cv'][xvar]
            y = self.data[datakey]['cv'][yvar]
        loadfig = None
        if not figname in self.figname:
            self.figname.append(figname)
        if figname in self.figs:
            loadfig = self.figs[figname]

        figpath = self.plotFilenameLineEdit.text()
        figpath, figfile = '/'.join(figpath.split('/')[:-1]), figpath.split('/')[-1]
        if self.plotFilenameLineEdit.text() == "" or self.plotFilenameLineEdit.text() == "*.png":
            figpath, figfile = self.outpath, figname
        self.figs[figname] = make_plot(x, y, figpath, figfile, xrange=xrange, yrange=yrange, xtitle=xtitle,
                                       ytitle=ytitle, title=title,
                                       lbl=lbl, one_to_one=one_to_one, dpi=dpi, color=color,
                                       annot_mask=annot_mask, cmap=cmap,
                                       colortitle=colortitle, loadfig=loadfig, marker=marker, linestyle=linestyle)

    def get_choices(self):
        try:
            self.vars_level0 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[self.chooseDataComboBox.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = self.vars_level1[self.vars_level0 != 'wvl']
            self.vars_level0 = self.vars_level0[self.vars_level0 != 'wvl']
            self.vars_level1 = list(self.vars_level1[self.vars_level0 != 'masked'])
            self.vars_level0 = list(self.vars_level0[self.vars_level0 != 'masked'])
            try:
                self.vars_level0 = [i for i in self.vars_level0 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except:
                pass
            try:
                self.vars_level1 = [i for i in self.vars_level1 if
                                    'Unnamed' not in str(i)]  # remove unnamed columns from choices
            except:
                pass
            choices = self.vars_level1

        except:
            try:
                choices = self.data[self.chooseDataComboBox.currentText()].columns.values
            except:
                choices = ['No valid choices']
        return choices

    def get_minmax(self, objmin, objmax, var):
        try:
            varind = self.vars_level1.index(var)
            vartuple = (self.vars_level0[varind], self.vars_level1[varind])
            vardata = self.data[self.chooseDataComboBox.currentText()].df[vartuple]
        except:
            try:
                vardata = self.data[self.chooseDataComboBox.currentText()]['cv'][var]
            except:
                vardata = [0, 0]
        try:
            varmin = float(np.min(vardata))
            varmax = float(np.max(vardata))
            objmin.setValue(varmin)
            objmax.setValue(varmax)
        except:
            objmin.setValue(0)
            objmax.setValue(1)

    def on_plotFilenamePushButton_clicked(self):
        filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None, "Save Plot", self.outpath, "(*.png)")
        self.plotFilenameLineEdit.setText(filename)
        if self.plotFilenameLineEdit.text() == "":
            self.plotFilenameLineEdit.setText("*.png")


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = Plot()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupbox = QtWidgets.QGroupBox(Form)
        self.groupbox.setObjectName("groupbox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupbox)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.polynomialOrderLabel = QtWidgets.QLabel(self.groupbox)
        self.polynomialOrderLabel.setObjectName("polynomialOrderLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.polynomialOrderLabel)
        self.polynomialOrderSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.polynomialOrderSpinBox.setObjectName("polynomialOrderSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.polynomialOrderSpinBox)
        self.maximumNumOfIterationsLabel = QtWidgets.QLabel(self.groupbox)
        self.maximumNumOfIterationsLabel.setObjectName("maximumNumOfIterationsLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maximumNumOfIterationsLabel)
        self.maximumNumOfIterationsDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupbox)
        self.maximumNumOfIterationsDoubleSpinBox.setObjectName("maximumNumOfIterationsDoubleSpinBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maximumNumOfIterationsDoubleSpinBox)
        self.toleranceLabel = QtWidgets.QLabel(self.groupbox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.groupbox)
        self.toleranceDoubleSpinBox.setObjectName("toleranceDoubleSpinBox")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.toleranceDoubleSpinBox)
        self.verticalLayout.addWidget(self.groupbox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.polynomialOrderLabel.setText(("Polynomial Order"))
        self.maximumNumOfIterationsLabel.setText(("Maximum num of Iterations"))
        self.toleranceLabel.setText(("Tolerance"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from point_spectra_gui.ui import ARD
from point_spectra_gui.ui import BaselineRemoval
from point_spectra_gui.ui import BayesianRidge
from point_spectra_gui.ui import CrossValidation
from point_spectra_gui.ui import DimensionalityReduction
from point_spectra_gui.ui import ElasticNet
from point_spectra_gui.ui import GP
from point_spectra_gui.ui import Interpolation
from point_spectra_gui.ui import KRR
from point_spectra_gui.ui import LARS
from point_spectra_gui.ui import Lasso
from point_spectra_gui.ui import LassoLARS
from point_spectra_gui.ui import LoadData
from point_spectra_gui.ui import MainWindow
from point_spectra_gui.ui import MaskData
from point_spectra_gui.ui import MultiplyByVector
from point_spectra_gui.ui import Normalization
from point_spectra_gui.ui import OLS
from point_spectra_gui.ui import OMP
from point_spectra_gui.ui import OutputFolder
from point_spectra_gui.ui import PeakAreas
from point_spectra_gui.ui import Plot
from point_spectra_gui.ui import Plot_ICA_PCA
from point_spectra_gui.ui import PlotSpectra
from point_spectra_gui.ui import PLS
from point_spectra_gui.ui import ReadChemCamData
from point_spectra_gui.ui import RegressionPredict
from point_spectra_gui.ui import RegressionTrain
from point_spectra_gui.ui import RemoveRows
from point_spectra_gui.ui import Ridge
from point_spectra_gui.ui import SplitDataset
from point_spectra_gui.ui import StratifiedFolds
from point_spectra_gui.ui import SubmodelPredict
from point_spectra_gui.ui import SVR












from PyQt5 import QtWidgets
from pysat.spectral.baseline_code.median import MedianFilter

from point_spectra_gui.ui.Median import Ui_Form
from point_spectra_gui.util.BasicFunctionality import Basics


class Ui_Form(Ui_Form, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        br = MedianFilter()
        self.windowSizeSpinBox.setValue(br.window_)

    def function(self):
        methodParameters = {'window_': int(self.windowSizeSpinBox.value())}
        return methodParameters


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import pandas as pd
from PyQt5 import QtWidgets
from pysat.spectral.spectral_data import spectral_data

from point_spectra_gui.ui.LoadData import Ui_loadData
from point_spectra_gui.util.BasicFunctionality import Basics


class LoadData(Ui_loadData, Basics):
    def setupUi(self, Form):
        super().setupUi(Form)
        Basics.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.newFilePushButton.clicked.connect(lambda: self.on_getDataButton_clicked(self.fileNameLineEdit))

    def on_getDataButton_clicked(self, lineEdit):
        filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None, "Open Data File", self.outpath, "(*.csv)")
        lineEdit.setText(filename)
        if lineEdit.text() == "":
            lineEdit.setText("*.csv")

    def function(self):
        params = self.getGuiParams()
        filename = params['fileNameLineEdit']
        keyname = params['dataSetNameLineEdit']
        print('Loading data file: ' + str(filename))
        if keyname in self.datakeys:
            print("That \"Data Set Name\" is already in use. Try something else.")
        else:
            self.datakeys.append(keyname)
            self.data[keyname] = spectral_data(pd.read_csv(filename, header=[0, 1], verbose=True))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = LoadData()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from point_spectra_gui.core.baselineRemovalMethods import ALS
from point_spectra_gui.core.baselineRemovalMethods import AirPLS
from point_spectra_gui.core.baselineRemovalMethods import CCAM
from point_spectra_gui.core.baselineRemovalMethods import Dietrich
from point_spectra_gui.core.baselineRemovalMethods import FABC
from point_spectra_gui.core.baselineRemovalMethods import KK
from point_spectra_gui.core.baselineRemovalMethods import Mario
from point_spectra_gui.core.baselineRemovalMethods import Mario
from point_spectra_gui.core.baselineRemovalMethods import Median
from point_spectra_gui.core.baselineRemovalMethods import Polyfit
from point_spectra_gui.core.baselineRemovalMethods import Rubberband



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupbox = QtWidgets.QGroupBox(Form)
        self.groupbox.setObjectName("groupbox")
        self.formLayout_2 = QtWidgets.QFormLayout(self.groupbox)
        self.formLayout_2.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout_2.setObjectName("formLayout_2")
        self.topWidthLabel = QtWidgets.QLabel(self.groupbox)
        self.topWidthLabel.setObjectName("topWidthLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.topWidthLabel)
        self.topWidthSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.topWidthSpinBox.setObjectName("topWidthSpinBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.topWidthSpinBox)
        self.bottomWidthLabel = QtWidgets.QLabel(self.groupbox)
        self.bottomWidthLabel.setObjectName("bottomWidthLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.bottomWidthLabel)
        self.bottomWidthSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.bottomWidthSpinBox.setObjectName("bottomWidthSpinBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.bottomWidthSpinBox)
        self.exponentLabel = QtWidgets.QLabel(self.groupbox)
        self.exponentLabel.setObjectName("exponentLabel")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.exponentLabel)
        self.exponentSpinBox = QtWidgets.QSpinBox(self.groupbox)
        self.exponentSpinBox.setObjectName("exponentSpinBox")
        self.formLayout_2.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.exponentSpinBox)
        self.tangentLabel = QtWidgets.QLabel(self.groupbox)
        self.tangentLabel.setObjectName("tangentLabel")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.tangentLabel)
        self.tangentCheckBox = QtWidgets.QCheckBox(self.groupbox)
        self.tangentCheckBox.setObjectName("tangentCheckBox")
        self.formLayout_2.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.tangentCheckBox)
        self.verticalLayout.addWidget(self.groupbox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.topWidthLabel.setText(("Top Width"))
        self.bottomWidthLabel.setText(("Bottom Width"))
        self.exponentLabel.setText(("Exponent"))
        self.tangentLabel.setText(("Tangent"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

